# Changelog

## [Unreleased](https://github.com/CasperWA/turtle-canon/tree/HEAD)

[Full Changelog](https://github.com/CasperWA/turtle-canon/compare/v0.1.1...HEAD)

**Fixed bugs:**

- Fix wrong version change regex in release workflow [\#256](https://github.com/CasperWA/turtle-canon/issues/256)

## [v0.1.1](https://github.com/CasperWA/turtle-canon/tree/v0.1.1) (2025-02-19)

[Full Changelog](https://github.com/CasperWA/turtle-canon/compare/v0.1.0...v0.1.1)

## Upgrade package metadata and basic support

Expand Python version support to include 3.11, 3.12, and 3.13.

Update CI/CD workflows to properly update support for the latest RDFLib versions.

First release on [PyPI](https://pypi.org/project/turtle-canon).

**Implemented enhancements:**

- Publish on PyPI [\#253](https://github.com/CasperWA/turtle-canon/issues/253)
- Open Python version support [\#249](https://github.com/CasperWA/turtle-canon/issues/249)

**Merged pull requests:**

- Remove bad escape backslash [\#257](https://github.com/CasperWA/turtle-canon/pull/257) ([CasperWA](https://github.com/CasperWA))
- Publish to PyPI upon release [\#254](https://github.com/CasperWA/turtle-canon/pull/254) ([CasperWA](https://github.com/CasperWA))
- Expand on supported Python version [\#252](https://github.com/CasperWA/turtle-canon/pull/252) ([CasperWA](https://github.com/CasperWA))
- \[pre-commit.ci\] pre-commit autoupdate [\#251](https://github.com/CasperWA/turtle-canon/pull/251) ([pre-commit-ci[bot]](https://github.com/apps/pre-commit-ci))
- \[pre-commit.ci\] pre-commit autoupdate [\#248](https://github.com/CasperWA/turtle-canon/pull/248) ([pre-commit-ci[bot]](https://github.com/apps/pre-commit-ci))
- \[pre-commit.ci\] pre-commit autoupdate [\#246](https://github.com/CasperWA/turtle-canon/pull/246) ([pre-commit-ci[bot]](https://github.com/apps/pre-commit-ci))
- \[pre-commit.ci\] pre-commit autoupdate [\#245](https://github.com/CasperWA/turtle-canon/pull/245) ([pre-commit-ci[bot]](https://github.com/apps/pre-commit-ci))
- \[pre-commit.ci\] pre-commit autoupdate [\#243](https://github.com/CasperWA/turtle-canon/pull/243) ([pre-commit-ci[bot]](https://github.com/apps/pre-commit-ci))
- Update CI for generating new test files for RDFlib [\#242](https://github.com/CasperWA/turtle-canon/pull/242) ([CasperWA](https://github.com/CasperWA))
- \[pre-commit.ci\] pre-commit autoupdate [\#241](https://github.com/CasperWA/turtle-canon/pull/241) ([pre-commit-ci[bot]](https://github.com/apps/pre-commit-ci))
- Dependabot/GitHub actions/ci/dependabot updates/sintef/ci cd 2.8.3 [\#240](https://github.com/CasperWA/turtle-canon/pull/240) ([CasperWA](https://github.com/CasperWA))
- Dependabot/GitHub actions/ci/dependabot updates/codecov/codecov action 5 [\#239](https://github.com/CasperWA/turtle-canon/pull/239) ([CasperWA](https://github.com/CasperWA))
- Create dedicated workflow for rdflib test files [\#238](https://github.com/CasperWA/turtle-canon/pull/238) ([CasperWA](https://github.com/CasperWA))
- Add a shebang to `changes` [\#237](https://github.com/CasperWA/turtle-canon/pull/237) ([CasperWA](https://github.com/CasperWA))
- Move changes to dedicated file [\#236](https://github.com/CasperWA/turtle-canon/pull/236) ([CasperWA](https://github.com/CasperWA))
- Remove usage of ci/dependency-updates [\#234](https://github.com/CasperWA/turtle-canon/pull/234) ([CasperWA](https://github.com/CasperWA))
- Add new canonized test files [\#233](https://github.com/CasperWA/turtle-canon/pull/233) ([CasperWA](https://github.com/CasperWA))
- \[Auto-generated\] Update dependencies [\#201](https://github.com/CasperWA/turtle-canon/pull/201) ([CasperWA](https://github.com/CasperWA))

## [v0.1.0](https://github.com/CasperWA/turtle-canon/tree/v0.1.0) (2024-01-12)

[Full Changelog](https://github.com/CasperWA/turtle-canon/compare/v0.0.1...v0.1.0)

**Implemented enhancements:**

- Upgrade minimum Python support to 3.10 [\#178](https://github.com/CasperWA/turtle-canon/issues/178)
- Refresh Python code [\#177](https://github.com/CasperWA/turtle-canon/issues/177)
- Support passing several files to CLI [\#21](https://github.com/CasperWA/turtle-canon/issues/21)
- Create `pre-commit` hook for Turtle Canon [\#19](https://github.com/CasperWA/turtle-canon/issues/19)
- Update code base for code coverage [\#13](https://github.com/CasperWA/turtle-canon/issues/13)
- Use `rdflib` directly [\#2](https://github.com/CasperWA/turtle-canon/issues/2)
- Unit tests [\#1](https://github.com/CasperWA/turtle-canon/issues/1)
- New tests for different sources [\#15](https://github.com/CasperWA/turtle-canon/pull/15) ([CasperWA](https://github.com/CasperWA))
- Add codecov config file + checks for it [\#11](https://github.com/CasperWA/turtle-canon/pull/11) ([CasperWA](https://github.com/CasperWA))
- Extend tests [\#7](https://github.com/CasperWA/turtle-canon/pull/7) ([CasperWA](https://github.com/CasperWA))

**Fixed bugs:**

- RDFLib vulnerability [\#71](https://github.com/CasperWA/turtle-canon/issues/71)
- GH GraphQL type issue for auto-merge workflow [\#42](https://github.com/CasperWA/turtle-canon/issues/42)
- New updates to RDFlib not reflected in testing [\#30](https://github.com/CasperWA/turtle-canon/issues/30)
- Use Python 3.9 in CI [\#24](https://github.com/CasperWA/turtle-canon/issues/24)

**Closed issues:**

- Instantiate git profile in CI updating dependency [\#92](https://github.com/CasperWA/turtle-canon/issues/92)
- pylint is failing [\#56](https://github.com/CasperWA/turtle-canon/issues/56)
- Have dependabot use correct labels [\#9](https://github.com/CasperWA/turtle-canon/issues/9)

**Merged pull requests:**

- Upgrade code base [\#179](https://github.com/CasperWA/turtle-canon/pull/179) ([CasperWA](https://github.com/CasperWA))
- Run git init in CI [\#93](https://github.com/CasperWA/turtle-canon/pull/93) ([CasperWA](https://github.com/CasperWA))
- Move pylint disable statement [\#57](https://github.com/CasperWA/turtle-canon/pull/57) ([CasperWA](https://github.com/CasperWA))
- Use `ID!` type instead of `String!` [\#43](https://github.com/CasperWA/turtle-canon/pull/43) ([CasperWA](https://github.com/CasperWA))
- Use Python 3.9 in CI/CD throughout [\#25](https://github.com/CasperWA/turtle-canon/pull/25) ([CasperWA](https://github.com/CasperWA))
- Support multiple files for CLI + add `--fail-fast` option [\#22](https://github.com/CasperWA/turtle-canon/pull/22) ([CasperWA](https://github.com/CasperWA))
- Create Turtle Canon pre-commit hook [\#20](https://github.com/CasperWA/turtle-canon/pull/20) ([CasperWA](https://github.com/CasperWA))
- Add tests according to missing coverage [\#14](https://github.com/CasperWA/turtle-canon/pull/14) ([CasperWA](https://github.com/CasperWA))
- Add coverage and CI badges to README [\#12](https://github.com/CasperWA/turtle-canon/pull/12) ([CasperWA](https://github.com/CasperWA))
- Update label for created single dependency PR [\#10](https://github.com/CasperWA/turtle-canon/pull/10) ([CasperWA](https://github.com/CasperWA))
- Add tests & use RDFlib [\#6](https://github.com/CasperWA/turtle-canon/pull/6) ([CasperWA](https://github.com/CasperWA))

## [v0.0.1](https://github.com/CasperWA/turtle-canon/tree/v0.0.1) (2021-12-02)

[Full Changelog](https://github.com/CasperWA/turtle-canon/compare/2a329063accd8247d99ffbc2821ec5f56fbdd2dc...v0.0.1)



\* *This Changelog was automatically generated by [github_changelog_generator](https://github.com/github-changelog-generator/github-changelog-generator)*
